#include <algorithm>
#include <vector>
#include <cstdio>
#include <cstdlib>

using namespace std;

struct Intervalo {
    Intervalo(unsigned a, unsigned b, unsigned c) : inicio(a), fim(b), valor(c) {}
    
    unsigned inicio;
    unsigned fim;
    unsigned valor;
    
    bool operator<(const Intervalo& o) const {
        if(inicio != o.inicio) return inicio < o.inicio;
        if(fim    != o.fim)    return fim    < o.fim;
        return valor < o.valor;
    }
};

struct Arvore {
    Arvore(const vector<Intervalo>& iv, int emenor = -1, int emaior = -1) {
        // intervalo unitário ou vazio
        if(iv.size() <= 1) {
            sobre  = iv;
            esq    = dir = 0;
            centro = -1;
            return;
        }
        
        if(emenor == -1 && emaior == -1) {
            sort(iv.begin(), iv.end());
            menor = iv[0].inicio;
            maior = iv[0].fim;
            for(int i = 1, e = iv.size(); i < e; ++i)
                if(iv[i].fim > maior) maior = iv[i].fim;
        } else {
            menor = emenor;
            maior = emaior;
        }
        
        // quebrar em intervalos menores
        centro = (menor + maior) / 2;
        vector<Intervalo> esqs, dirs;
        
        for(int i = 0, e = iv.size(); i < e; ++i) {
            if(iv[i].fim < centro) {
                esqs.push_back(iv[i]);
                continue;
            }
            if(iv[i].inicio > centro) {
                dirs.push_back(iv[i]);
                continue;
            }
            sobre.push_back(iv[i]);
        }
        
        esq = new Arvore(esqs, menor, centro);
        dir = new Arvore(dirs, centro, maior);
    }
    
    ~Arvore() {
        if(esq) delete esq;
        if(dir) delete dir;
    }
    
    int busca(unsigned inicio, unsigned fim) {
        int qt = 0;
        
        // busca no nó atual
        for(int i = 0, e = sobre.size(); i < e; ++i)
            if(inicio <= sobre[i].fim && fim >= sobre[i].inicio)
                qt += sobre[i].valor;
        
        // busca na esquerda se precisar
        if(esq && inicio <= centro) qt += esq->busca(inicio, fim);
        
        // busca na direita se precisar
        if(dir && inicio >= centro) qt += esq->busca(inicio, fim);
        
        return qt;
    }
    
    unsigned centro;
    vector<Intervalo> sobre;
    Arvore *dir, *esq;
};

int main() {
    while(true) {
        vector<Intervalo> v;
        int N, M;
        scanf("%d", &N);
        if(N == 0) break;
        
        for(int i = 0; i < N; ++i) {
            int a, b, c;
            scanf("%d %d %d", &a, &b, &c);
            v.push_back(Intervalo(a,b,c));
        }
        
        Arvore arvore(v);
        
        scanf("%d", &M);
        
        for(int i = 0; i < M; ++i) {
            int a, b;
            scanf("%d %d", &a, &b);
            printf("%d\n", arvore.busca(a, b));
        }
    }
    
    return 0;
}
